.. meta::
    :description lang=en:
        A Python function to extract structured elements from text lists, and
        get basic statistics about them. Hashtags, mentions, numbers,
        questions, and emoji are some of the available entities to extract.

.. automodule:: advertools.extract
   :members:
   :undoc-members:
   :show-inheritance:
